# Создать приём

**POST**: `https://api3.medelement.com/v1/doctor/reception`

## Параметры:

| Название               | Тип      | Описание                  |
| ---------------------- | -------- | ------------------------- |
| patient_code\*         | Bigint   | Идентификатор пациента    |
| specialist_code\*      | Bigint   | Идентификатор специалиста |
| company_cabinet_code\* | Bigint   | Идентификатор кабинета    |
| starttime\*            | String   | Начало приёма             |
| endtime\*              | String   | Завершение приёма         |
| nomenclature_code      | Bigint   | Услуга                    |
| description            | String   | Примечание                |
| color_code             | Smallint | Цвет приема в календаре   |

### Коды цветов:

| Код цвета | Цвет            |
| --------- | --------------- |
| 0         | Без выделения   |
| 1         | Красный         |
| 2         | Зеленый         |
| 3         | Голубой         |
| 4         | Желтый          |
| 5         | Фиолетовый      |
| 6         | Оранжевый       |
| 7         | Серый           |
| 8         | Коричневый      |
| 9         | Темно бирюзовый |

\* обязательные параметры

## Ответ:

HTTP/1.1 201 OK

```json
{
    "message": "Reception created",
    "reception_code": 123321123321123
}
```

## Описание полей ответа:

| Название       | Тип    | Описание                    |
| -------------- | ------ | --------------------------- |
| reception_code | Bigint | Идентификатор нового приёма |
